@@ -3,14 +3,15 @@ zelig.default <- function(formula, model, data, by = NULL, save.data =
   fn1 <- paste("zelig2", model, sep = "")
   fn2 <- paste("zelig3", model, sep = "")
   if (!exists(fn1))
-    stop(model, "not supported. Type help.zelig(\"models\") to list supported models.")
+    stop(model,
+         "not supported. Type help.zelig(\"models\") to list supported models.")
   mf <- zelig.call <- match.call(expand.dots = TRUE)
   zelig.call[[1]] <- as.name("zelig")
   if (missing(by))
     by <- NULL
   N <- M <- 1
   object <- list()
-  if (!is.data.frame(data))
+  if ("mi" %in% class(data))
     M <- length(data)
   if (M > 1)
     dat <- data[[1]]
@@ -74,5 +75,5 @@ zelig.default <- function(formula, model, data, by = NULL, save.data =
     class(object) <- "strata"
     names(object) <- lev
   }
-  object
+  return(object)
 }
